# Modelled source apportionment annual averages 2019 – gridded 

This document describes a dataset which was generated as part of the
Breathe London pilot project. Keep reading to find key information,
description, notes and a full schema.

## Version control

| Version no. | Date       | Author      | Changes                                 |
|-------------|------------|-------------|-----------------------------------------|
| 1.0         | 09/09/2021 | Greg Slater | Initial release of document and dataset |
|             |            |             |                                         |
|             |            |             |                                         |

## Key information

| Data category          | Modelled concentrations                             |
|------------------------|-----------------------------------------------------|
| Pollutants             | NOx (µg/m³), PM<sub>2.5</sub> (µg/m³)               |
| Spatial resolution     | 10m grid                                            |
| Temporal resolution    | Annual average                                      |
| Date range             | 2019                                                |
| Source                 | Cambridge Environmental Research Consultants (CERC) |
| Model (if appropriate) | Hotspot 2019                                        |
| Format                 | space-delimited variables with file extension .xyz  |
| Related datasets       |                                                     |
| Big query tables       | Yes                                                 |
| No. files              | 51                                                  |

## Description

This dataset estimates the concentration of NOx and PM2.5 from specific
emissions sources at a high resolution (10x10m) across Greater London.

Source apportionment methods: ADMS-Urban model used emissions of NOx and
PM2.5 taken from the London Atmospheric Emissions Inventory (LAEI)
published by the Greater London Authority (GLA). This work used ‘LAEI
2013’, which was published in 2016, has a base year of 2013 and includes
projections for 2020. Specifically, this work used annual average values
for 2019, obtained by interpolating between the base year values and the
projections for 2020. Pollution concentrations were modelled at 1m above
ground.

## Additional documentation

Full details of the modelling approach can be found in the Breathe
London technical report (Part 4):
https://www.globalcleanair.org/bl-pilot-final-technical-report/

For visualization in a web application see:
https://www.globalcleanair.org/solutions-and-resources/london-pollution-sources-map/

## Storage location(s)

Model ouput files:
<https://console.cloud.google.com/storage/browser/london-sourceapp-public/>

## License

To the extent possible under law, Environmental Defense Fund has waived
all copyright and related or neighboring rights to this dataset. This
work is published from: United Kingdom.

## Data Citation

Data citation promotes sound, reproducible, and reusable scientific
research. This dataset should be cited as follows:

CERC. (2021). Annual average pollution source apportionment at gridded
receptors. (Version 1.0) \[data files\]. Cambridge Environmental
Research Consultants \[producer\]. Environmental Defense Fund
\[distributor\].

## Sharing

Data is available on request.

## Notes

### Model output files

Each separate file records the modelled pollution concentration from a
particular source category at locations in a 10x10 metre grid covering
Greater London. There are 24 source categories for NOx and 27 source
categories for PM2.5, meaning 51 files in total. The grid size is
6091x5191, meaning there are 31,618,381 records per file. The modelled
area is smaller than the grid area, and values outside the modelled area
are recorded as -999. The files can be read into GIS software as raster
data.

This data does not include a separate file for background concentrations
as these are constant across the entire modelled area. An annual average
background concentration value for each pollutant can be found below and
added to calculations as necessary.

### Background values

CERC provided the background values below.

NO<sub>x</sub>: 9.67 µg/m³

PM<sub>2.5</sub>: 8.37 µg/m³

## Schema

### Model output files

The file data from CERC is stored in 51 .xyz files, one for each
pollutant and source. Each file is approximately 850mb in size and
follows the file naming convention below:

> \[Pollutant\]\_\[SourceCategory\]\_\[Source\]\_London\_2019.xyz
>
> E.g. NOx\_RoadTransport\_ArticulatedHGVs\_London\_2019.xyz

The .xyz files store data without headers and separated by spaces. The
three fields are as follows:

x: OSGB (Ordnance Survey Great Britain) Co-Ordinates, Eastings

y: OSGB (Ordnance Survey Great Britain) Co-Ordinates, Northings

value: modelled concentration (µg/m³)

The table below lists the different pollutants, source categories, and
sources included in the model.

| pollutants                       | source\_category          | source                |
|----------------------------------|---------------------------|-----------------------|
| NO<sub>x,</sub> PM<sub>2.5</sub> | CommercialAndDomesticFuel | CommercialGas         |
| NO<sub>x,</sub> PM<sub>2.5</sub> | CommercialAndDomesticFuel | CommercialOtherFuels  |
| NO<sub>x,</sub> PM<sub>2.5</sub> | CommercialAndDomesticFuel | DomesticGas           |
| NO<sub>x,</sub> PM<sub>2.5</sub> | CommercialAndDomesticFuel | DomesticOtherFuels    |
| PM<sub>2.5</sub>                 | IndustrialAndConstruction | Dust                  |
| NO<sub>x,</sub> PM<sub>2.5</sub> | IndustrialAndConstruction | Industry              |
| NO<sub>x,</sub> PM<sub>2.5</sub> | IndustrialAndConstruction | NRMM                  |
| NO<sub>x,</sub> PM<sub>2.5</sub> | Other                     | Agriculture           |
| NO<sub>x,</sub> PM<sub>2.5</sub> | Other                     | HouseAndGarden        |
| NO<sub>x,</sub> PM<sub>2.5</sub> | Other                     | Residual              |
| NO<sub>x,</sub> PM<sub>2.5</sub> | Other                     | STW                   |
| PM<sub>2.5</sub>                 | Other                     | WasteTransferServices |
| NO<sub>x,</sub> PM<sub>2.5</sub> | OtherTransport            | Aviation              |
| NO<sub>x,</sub> PM<sub>2.5</sub> | OtherTransport            | CommercialShipping    |
| NO<sub>x,</sub> PM<sub>2.5</sub> | OtherTransport            | PassengerShipping     |
| NO<sub>x,</sub> PM<sub>2.5</sub> | OtherTransport            | Rail                  |
| NO<sub>x,</sub> PM<sub>2.5</sub> | RoadTransport             | ArticulatedHGVs       |
| NO<sub>x,</sub> PM<sub>2.5</sub> | RoadTransport             | DieselCars            |
| NO<sub>x,</sub> PM<sub>2.5</sub> | RoadTransport             | DieselLGVs            |
| NO<sub>x,</sub> PM<sub>2.5</sub> | RoadTransport             | Motorcycles           |
| NO<sub>x,</sub> PM<sub>2.5</sub> | RoadTransport             | NonTfLBusesandCoaches |
| NO<sub>x,</sub> PM<sub>2.5</sub> | RoadTransport             | PetrolCars            |
| NO<sub>x,</sub> PM<sub>2.5</sub> | RoadTransport             | PetrolLGVs            |
| NO<sub>x,</sub> PM<sub>2.5</sub> | RoadTransport             | RigidHGVs             |
| NO<sub>x,</sub> PM<sub>2.5</sub> | RoadTransport             | Taxis                 |
| NO<sub>x,</sub> PM<sub>2.5</sub> | RoadTransport             | TfLBuses              |
| PM<sub>2.5</sub>                 | RoadTransport             | BrakeTyreandRoadWear  |
